@@ -12,7 +12,6 @@
 
 #include "config.h"
 #include <gdk/gdkkeysyms.h>
-#include <libgnome/gnome-macros.h>
 #include <bonobo/bonobo-i18n.h>
 #include <bonobo/bonobo-plug.h>
 #include <bonobo/bonobo-control.h>
@@ -21,6 +20,7 @@
 #include <gdk/gdkx.h>
 #elif defined (GDK_WINDOWING_WIN32)
 #include <gdk/gdkwin32.h>
+#elif defined (GDK_WINDOWING_QUARTZ)
 #else
 #error Port to this GDK backend
 #endif
@@ -34,8 +34,7 @@ enum {
 	PROP_FORWARD_EVENTS
 };
 
-GNOME_CLASS_BOILERPLATE (BonoboPlug, bonobo_plug,
-			 GObject, GTK_TYPE_PLUG)
+G_DEFINE_TYPE (BonoboPlug, bonobo_plug, GTK_TYPE_PLUG)
 
 /**
  * bonobo_plug_construct:
@@ -90,7 +89,7 @@ bonobo_plug_new_for_display (GdkDisplay *display,
 
 	bonobo_plug_construct_full (plug, display, socket_id);
 
-	dprintf ("bonobo_plug_new => %p\n", plug);
+	dbgprintf ("bonobo_plug_new => %p\n", plug);
 
 	return GTK_WIDGET (plug);
 }
@@ -130,7 +129,7 @@ bonobo_plug_set_control (BonoboPlug    *plug,
 	if (plug->control == control)
 		return;
 
-	dprintf ("bonobo_plug_set_control (%p, %p) [%p]\n",
+	dbgprintf ("bonobo_plug_set_control (%p, %p) [%p]\n",
 		 plug, control, plug->control);
 
 	old_control = plug->control;
@@ -153,7 +152,7 @@ static gboolean
 bonobo_plug_delete_event (GtkWidget   *widget,
 			  GdkEventAny *event)
 {
-	dprintf ("bonobo_plug_delete_event %p\n", widget);
+	dbgprintf ("bonobo_plug_delete_event %p\n", widget);
 
 	return FALSE;
 }
@@ -163,9 +162,9 @@ bonobo_plug_realize (GtkWidget *widget)
 {
 	BonoboPlug *plug = (BonoboPlug *) widget;
 
-	dprintf ("bonobo_plug_realize %p\n", plug);
+	dbgprintf ("bonobo_plug_realize %p\n", plug);
 
-	GTK_WIDGET_CLASS (parent_class)->realize (widget);
+	GTK_WIDGET_CLASS (bonobo_plug_parent_class)->realize (widget);
 }
 
 static void
@@ -173,18 +172,18 @@ bonobo_plug_unrealize (GtkWidget *widget)
 {
 	BonoboPlug *plug = (BonoboPlug *) widget;
 
-	dprintf ("bonobo_plug_unrealize %p\n", plug);
+	dbgprintf ("bonobo_plug_unrealize %p\n", plug);
 
-	GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
+	GTK_WIDGET_CLASS (bonobo_plug_parent_class)->unrealize (widget);
 }
 
 static void
 bonobo_plug_map (GtkWidget *widget)
 {
-	dprintf ("bonobo_plug_map %p at size %d, %d\n",
+	dbgprintf ("bonobo_plug_map %p at size %d, %d\n",
 		 widget, widget->allocation.width,
 		 widget->allocation.height);
-	GTK_WIDGET_CLASS (parent_class)->map (widget);
+	GTK_WIDGET_CLASS (bonobo_plug_parent_class)->map (widget);
 }
 
 static void
@@ -193,18 +192,18 @@ bonobo_plug_dispose (GObject *object)
 	BonoboPlug *plug = (BonoboPlug *) object;
 	GtkBin *bin_plug = (GtkBin *) object;
 
-	dprintf ("bonobo_plug_dispose %p\n", object);
+	dbgprintf ("bonobo_plug_dispose %p\n", object);
 
 	if (bin_plug->child) {
 		gtk_container_remove (
 			&bin_plug->container, bin_plug->child);
-		dprintf ("Removing child ...");
+		dbgprintf ("Removing child ...");
 	}
 
 	if (plug->control)
 		bonobo_plug_set_control (plug, NULL);
 
-	parent_class->dispose (object);
+	G_OBJECT_CLASS (bonobo_plug_parent_class)->dispose (object);
 }
 
 static void
@@ -215,7 +214,7 @@ bonobo_plug_finalize (GObject *object)
 	if (plug->priv)
 		g_free (plug->priv);
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (bonobo_plug_parent_class)->finalize (object);
 }
 
 static void
@@ -266,7 +265,7 @@ static void
 bonobo_plug_size_allocate (GtkWidget     *widget,
 			   GtkAllocation *allocation)
 {
-	dprintf ("bonobo_plug_size_allocate %p: (%d, %d), (%d, %d) %d! %s\n",
+	dbgprintf ("bonobo_plug_size_allocate %p: (%d, %d), (%d, %d) %d! %s\n",
 		 widget,
 		 allocation->x, allocation->y,
 		 allocation->width, allocation->height,
@@ -275,16 +274,16 @@ bonobo_plug_size_allocate (GtkWidget     *widget,
 		 g_type_name_from_instance ((gpointer)GTK_BIN (widget)->child):
 		 "No child!");
 
-	GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
+	GTK_WIDGET_CLASS (bonobo_plug_parent_class)->size_allocate (widget, allocation);
 }
 
 static void
 bonobo_plug_size_request (GtkWidget      *widget,
 			  GtkRequisition *requisition)
 {
-	GTK_WIDGET_CLASS (parent_class)->size_request (widget, requisition);
+	GTK_WIDGET_CLASS (bonobo_plug_parent_class)->size_request (widget, requisition);
 
-	dprintf ("bonobo_plug_size_request %p: %d, %d\n",
+	dbgprintf ("bonobo_plug_size_request %p: %d, %d\n",
 		 widget, requisition->width, requisition->height);
 }
 
@@ -294,9 +293,9 @@ bonobo_plug_expose_event (GtkWidget      *widget,
 {
 	gboolean retval;
 
-	retval = GTK_WIDGET_CLASS (parent_class)->expose_event (widget, event);
+	retval = GTK_WIDGET_CLASS (bonobo_plug_parent_class)->expose_event (widget, event);
 
-	dprintf ("bonobo_plug_expose_event %p (%d, %d), (%d, %d)"
+	dbgprintf ("bonobo_plug_expose_event %p (%d, %d), (%d, %d)"
 		 "%s (%d && %d == %d)\n",
 		 widget,
 		 event->area.x, event->area.y,
@@ -386,7 +385,7 @@ bonobo_plug_button_event (GtkWidget      *widget,
 }
 
 static void
-bonobo_plug_instance_init (BonoboPlug *plug)
+bonobo_plug_init (BonoboPlug *plug)
 {
 	BonoboPlugPrivate *priv;
 
